@@ -33,6 +33,10 @@
 #include <ucommon/socket.h>
 #endif
 
+#ifndef	_UCOMMON_STRING_H_
+#include <ucommon/string.h>
+#endif
+
 #ifndef	_UCOMMON_FSYS_H_
 #include <ucommon/fsys.h>
 #endif
@@ -49,7 +53,7 @@ NAMESPACE_UCOMMON
  */
 class __EXPORT IOBuffer
 {
-protected:
+public:
 	typedef enum {BUF_RD, BUF_WR, BUF_RDWR} type_t;
 
 private:
@@ -217,6 +221,15 @@ public:
 	inline size_t writeln(const char *string)
 		{return putline(string);};
 
+	/**
+	 * Method to write a string object.  This adds the current newline
+	 * character sequence to the output.
+	 * @param string to write.
+	 * @return number of characters actually written.
+	 */
+	inline size_t write(String& string)
+		{return putline(*string);};
+
 	/**
 	 * Method to read a line of input from the buffer.  This uses the current
 	 * newline character sequence to mark the end of line input.
@@ -227,6 +240,14 @@ public:
 	inline size_t readln(char *address, size_t size)
 		{return getline(address, size);};
 
+	/**
+	 * Method to read a line of input from the buffer.  This saves the result
+	 * into an already allocated string object.
+	 * @param string buffer to use.
+	 * @return number of characters actually read.
+	 */
+	size_t read(String& string);
+
 	/**
 	 * Method to read input data from the buffer.
 	 * @param address of buffer to use.
