@@ -178,6 +178,11 @@ public:
 	 */
 	void load(const char *path);
 
+	/**
+	 * Release and re-initialize keyfile.
+	 */
+	void release(void);
+
 	/**
 	 * Get a keydata section name.
 	 * @param section name to look for.
